@@ -18,7 +18,7 @@ use warnings ;
 use bytes ;
 our ($VERSION, $XS_VERSION, @ISA, @EXPORT, $AUTOLOAD);
 
-$VERSION = '2.000_09';
+$VERSION = '2.000_10';
 $XS_VERSION = $VERSION; 
 $VERSION = eval $VERSION;
 
@@ -158,11 +158,14 @@ sub Compress::Zlib::gzFile::gzread
     return _set_gzerr(Z_STREAM_ERROR())
         if $self->[1] ne 'inflate';
 
-    return 0 if $self->gzeof();
+    if ($self->gzeof()) {
+        # Zap the output buffer to match ver 1 behaviour.
+        $_[0] = "" ;
+        return 0 ;
+    }
 
     my $gz = $self->[0] ;
     my $status = $gz->read($_[0], defined $_[1] ? $_[1] : 4096) ; 
-    $_[0] = "" if ! defined $_[0] ;
     _save_gzerr($gz, 1);
     return $status ;
 }
@@ -1436,9 +1439,6 @@ The primary site for gzip is F<http://www.gzip.org>.
 
 
 
-
-
-
 =head1 AUTHOR
 
 This module was written by Paul Marquess, F<pmqs@cpan.org>. 
